==> Blind-src-V2.46.zip: Blind-2.46/version.c <==
static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.46/RCS/version.c,v 2.46 1997/04/18 12:06:12 zeus Exp zeus $";

/*
 *
 * $Log: version.c,v $
 * Revision 2.46  1997/04/18 12:06:12  zeus
 * *** empty log message ***
 *
 * Revision 2.45.0.1  1997/01/04  18:54:50  zeus
 * *** empty log message ***
 *
 * Revision 2.45  1996/12/31  23:40:54  zeus
 * *** empty log message ***
 *
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * Revision 2.42  1994/05/17  13:43:15  bampton
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * Revision 2.38  1993/09/27  17:15:54  bampton
 * Revision 2.37  1993/09/07  20:50:32  bampton
 * Revision 2.36  1993/08/19  16:32:29  bampton
 * Revision 2.35  1993/08/14  15:46:12  bampton
 * Revision 2.33  1993/08/03  23:10:13  bampton
 * Revision 2.30  1993/07/14  14:59:26  bampton
 * Revision 0.0  1993/07/14  13:50:21  bampton
 */

#define NOTIMEB
#include "protos/common.h"
#include "protos/prototypes.h"
#include "protos/version.h"

void version_rcsid (void);
void
version_rcsid (void)
{
  printf ("%s\n",rcsid);
}

void
version_info (void)
{
  float ver=VER;

  printf ("Version: %4.2f\n",ver);
  printf ("Compiled with:\n");
#ifdef BACKUPS
  printf ("BACKUPS ");
#endif
#ifdef INTERACTIVE
  printf ("INTERACTIVE ");
#endif
#ifdef SPEED
  {
    int sp=SPEED;
    printf ("SPEED=%2d ",sp); 
  }
#endif
  printf ("V3 ");
  printf ("CARRYOVER ");
#ifdef KCMD
  printf ("KCMD ");
#endif
#ifdef PARTTECH
  printf ("PARTTECH ");
#endif
#ifdef RANDPLACE
  printf ("RANDPLACE ");
#endif
#ifdef MINSEP
  {
    double ms=MINSEP;
    printf ("MINSEP=%6.2f ",ms); 
  }
#endif 
#ifdef NEWGAME
  printf ("NEWGAME ");
#endif
#ifdef BALANCE
  printf ("BALANCE ");
#endif
#ifdef PREPROC
  printf ("PREPROC ");
#endif
#ifdef FORECAST
  printf ("FORECAST ");
#endif
#ifdef SMARTC
  printf ("SMARTC ");
#endif
#ifdef FORECASTNAMES
  printf ("FORECASTNAMES ");
#endif
#ifdef GAMENAME
  printf ("GAMENAME ");
#endif
#ifdef PASSWORDS
  printf ("PASSWORDS ");
#endif
#ifdef ZCMDOK
  printf ("ZCMDOK ");
#endif
#ifdef BOMBBUG
  printf ("BOMBBUG ");
#endif
  printf ("NONAMEBUG ");
  printf ("UPGRADE ");
#ifdef SIZEBUG
  printf ("SIZEBUG ");
#endif
#ifdef ULTRIX
  printf ("ULTRIX ");
#endif
#ifdef HPUX9
  printf ("HPUX9 ");
#endif
#ifdef SUNOS4
  printf ("SUNOS4 ");
#endif
#ifdef LINUX
  printf ("LINUX ");
#endif
#ifdef VERBOSE
  printf ("VERBOSE ");
#endif
  printf ("\n");
}

void
full_version(void)
{
  printf ("rcsid info\n");
#ifdef NEWGAME
  addplayer_rcsid();
  new_galaxy_rcsid ();
#else
  blind_rcsid();
  enterturn_rcsid();
  loadgame_rcsid();
  cmds_rcsid();
#ifdef FORECAST
  turn_rcsid();
#else
#ifndef PREPROC
  turn_rcsid();
#endif
#endif
#endif
#ifndef PREPROC
#ifndef NEWGAME
  battle_rcsid();
#endif
  savegame_rcsid();
#endif
  misc_rcsid();           
#ifdef NEWGAME
  new_game_rcsid();
#else
  a_cmd_rcsid();
  b_cmd_rcsid();
  c_cmd_rcsid();
  d_cmd_rcsid();
  e_cmd_rcsid();
  f_cmd_rcsid();
  g_cmd_rcsid();
  h_cmd_rcsid();
  i_cmd_rcsid();
  j_cmd_rcsid();
  k_cmd_rcsid();
  l_cmd_rcsid();
  m_cmd_rcsid();
  n_cmd_rcsid();
  o_cmd_rcsid();
  p_cmd_rcsid();
  r_cmd_rcsid();
  s_cmd_rcsid();
  t_cmd_rcsid();
  u_cmd_rcsid();
  w_cmd_rcsid();
  x_cmd_rcsid();
#ifdef PASSWORDS
  y_cmd_rcsid();
#endif
#endif
#ifndef NEWGAME
  report_status_rcsid();
  report_ships_rcsid();
#ifndef FORECAST
  report_battle_rcsid();
#endif
#endif
  report_planets_rcsid();
  report_map_rcsid();
#ifndef FORECAST
  report_gm_rcsid();
#endif
  report_main_rcsid();
  version_rcsid();
}

==> Blind-src-V2.47.zip: Blind-2.47/version.c <==
static char *rcsid = "$Header: /plaid/homes/zeus/Blind-2.47/RCS/version.c,v 2.47 1998/04/15 21:29:39 zeus Exp zeus $";

/*
 *
 * $Log: version.c,v $
 * Revision 2.47  1998/04/15 21:29:39  zeus
 * *** empty log message ***
 *
 * Revision 2.46  1997/04/18 12:06:12  zeus
 * Revision 2.45.0.1  1997/01/04  18:54:50  zeus
 * Revision 2.45  1996/12/31  23:40:54  zeus
 * Revision 2.44  1995/12/31  19:45:18  zeus
 * Revision 2.43  1995/03/20  01:43:09  zeus
 * Revision 2.42  1994/05/17  13:43:15  bampton
 * Revision 2.40  1994/03/09  20:22:55  bampton
 * Revision 2.38  1993/09/27  17:15:54  bampton
 * Revision 2.37  1993/09/07  20:50:32  bampton
 * Revision 2.36  1993/08/19  16:32:29  bampton
 * Revision 2.35  1993/08/14  15:46:12  bampton
 * Revision 2.33  1993/08/03  23:10:13  bampton
 * Revision 2.30  1993/07/14  14:59:26  bampton
 * Revision 0.0  1993/07/14  13:50:21  bampton
 */

#define NOTIMEB
#include "protos/common.h"
#include "protos/prototypes.h"
#include "protos/version.h"

void version_rcsid (void);
void
version_rcsid (void)
{
  printf ("%s\n",rcsid);
}

void
version_info (void)
{
  float ver=VER;

  printf ("Version: %4.2f\n",ver);
  printf ("Compiled with:\n");
#ifdef BACKUPS
  printf ("BACKUPS ");
#endif
#ifdef INTERACTIVE
  printf ("INTERACTIVE ");
#endif
#ifdef SPEED
  {
    int sp=SPEED;
    printf ("SPEED=%2d ",sp); 
  }
#endif
  printf ("V3 ");
  printf ("CARRYOVER ");
#ifdef KCMD
  printf ("KCMD ");
#endif
#ifdef PARTTECH
  printf ("PARTTECH ");
#endif
#ifdef RANDPLACE
  printf ("RANDPLACE ");
#endif
#ifdef MINSEP
  {
    double ms=MINSEP;
    printf ("MINSEP=%6.2f ",ms); 
  }
#endif 
#ifdef NEWGAME
  printf ("NEWGAME ");
#endif
#ifdef BALANCE
  printf ("BALANCE ");
#endif
#ifdef PREPROC
  printf ("PREPROC ");
#endif
#ifdef FORECAST
  printf ("FORECAST ");
#endif
#ifdef SMARTC
  printf ("SMARTC ");
#endif
#ifdef FORECASTNAMES
  printf ("FORECASTNAMES ");
#endif
#ifdef GAMENAME
  printf ("GAMENAME ");
#endif
#ifdef PASSWORDS
  printf ("PASSWORDS ");
#endif
#ifdef ZCMDOK
  printf ("ZCMDOK ");
#endif
#ifdef BOMBBUG
  printf ("BOMBBUG ");
#endif
  printf ("NONAMEBUG ");
  printf ("UPGRADE ");
#ifdef SIZEBUG
  printf ("SIZEBUG ");
#endif
#ifdef SUNOS4
  printf ("SUNOS4 ");
#endif
#ifdef HPUX9
  printf ("HPUX9 ");
#endif
#ifdef SOLARIS
  printf ("SOLARIS ");
#endif
#ifdef ULTRIX
  printf ("ULTRIX ");
#endif
#ifdef AIX
  printf ("AIX ");
#endif
#ifdef LINUX
  printf ("LINUX ");
#endif
#ifdef IRIX5
  printf ("IRIX5 ");
#endif
#ifdef IRIX6
  printf ("IRIX6 ");
#endif
#ifdef OSF1
  printf ("OSF1 ");
#endif
#ifdef OPENBSD2
  printf ("OPENBSD2 ");
#endif
#ifdef NETBSD12
  printf ("NETBSD12 ");
#endif
#ifdef FREEBSD2
  printf ("FREEBSD2 ");
#endif
#ifdef VERBOSE
  printf ("VERBOSE ");
#endif
  printf ("\n");
}

void
full_version(void)
{
  printf ("rcsid info\n");
#ifdef NEWGAME
  addplayer_rcsid();
  new_galaxy_rcsid ();
#else
  blind_rcsid();
  enterturn_rcsid();
  loadgame_rcsid();
  cmds_rcsid();
#ifdef FORECAST
  turn_rcsid();
#else
#ifndef PREPROC
  turn_rcsid();
#endif
#endif
#endif
#ifndef PREPROC
#ifndef NEWGAME
  battle_rcsid();
#endif
  savegame_rcsid();
#endif
  misc_rcsid();           
#ifdef NEWGAME
  new_game_rcsid();
#else
  a_cmd_rcsid();
  b_cmd_rcsid();
  c_cmd_rcsid();
  d_cmd_rcsid();
  e_cmd_rcsid();
  f_cmd_rcsid();
  g_cmd_rcsid();
  h_cmd_rcsid();
  i_cmd_rcsid();
  j_cmd_rcsid();
  k_cmd_rcsid();
  l_cmd_rcsid();
  m_cmd_rcsid();
  n_cmd_rcsid();
  o_cmd_rcsid();
  p_cmd_rcsid();
  r_cmd_rcsid();
  s_cmd_rcsid();
  t_cmd_rcsid();
  u_cmd_rcsid();
  w_cmd_rcsid();
  x_cmd_rcsid();
#ifdef PASSWORDS
  y_cmd_rcsid();
#endif
#ifdef ZCMDOK
  z_cmd_rcsid();
#endif
#endif
#ifndef NEWGAME
  report_status_rcsid();
  report_ships_rcsid();
#ifndef FORECAST
  report_battle_rcsid();
#endif
#endif
  report_planets_rcsid();
  report_map_rcsid();
#ifndef FORECAST
  report_gm_rcsid();
#endif
  report_main_rcsid();
  version_rcsid();
}
